@@ -2,8 +2,6 @@
 
 
 class Resource:
-    value = None
-
     def __init__(self, value):
         self.value = value
 
@@ -14,10 +12,10 @@ class Resource:
         return self.value < other.value
 
     def __repr__(self):
-        return self.value
+        return str(self)
 
     def __str__(self):
-        return self.value
+        return str(self.value)
 
     def __hash__(self):
         return hash(repr(self))
@@ -60,3 +58,6 @@ class BNode(Entity):
 class IRIRef(Entity):
     def __init__(self, value):
         super().__init__(value)
+
+    def __add__(self, other):
+        return IRIRef(self.value + str(other))
